/*
 *  Copyright (C) 2009 Mayibongwe S. Nkambule <msnkambule@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */


#ifndef WINDOW_H
#define WINDOW_H

#include <KDialog>
#include <QWidget>
#include <QProcess>
#include <QModelIndex>

class QPushButton;
class QStandardItemModel;
class QTreeView;
class QLineEdit;
class QToolButton;
class QComboBox;
class QSpinBox;
class QMessageBox;
class KPushButton;
class KProgressDialog;

namespace Ui
{
    class TagDialog;
}

class CWindow : public KDialog
{
    Q_OBJECT

public:
    CWindow(QWidget *parent = 0, Qt::WindowFlags f = 0);
	void setFiles(QStringList);

public slots:
    void addFiles();
    void setOutFolder();
    void convert();
	void cancel();
    void changeExtension();
    void fixOutputFiles(); //change Extension of already selected files
    void updateMessage();
    void ffmpegDone(int, QProcess::ExitStatus);
	void showMenu(QModelIndex );
	void rename();
	void remove();
	void makeFATName();
	void editMetadata();
	void freqChanged(QString);
	void bitRChanged(QString);
	void clearStatusIcons(); // remove fail/success icons

private:
	void closeEvent( QCloseEvent * event );
	void  keyPressEvent( QKeyEvent * event );
	void readSettings();
	void writeSettings();
    void findCodecs();
	void createActions();
    void setProgressDialog();	
    void runffmpeg();
	
	void hideTagColumns();

    QPushButton *m_convertButton;
	QPushButton *addFileBtn;

    QTreeView *m_filelistview;
    QStandardItemModel *m_model;
	
    QLineEdit *outfolderEdit;
    KPushButton *openfolderBtn;

    QComboBox *m_codecBox;
    QLineEdit *m_extension;
    QSpinBox *m_channelsBox;
    QComboBox *m_freqBox;
    QComboBox *m_bitrBox;

    QString lastDestDir, lastSourceDir;

    QProcess *m_ffmpegProc;
    KProgressDialog *m_progressDlg;
    int m_converted;
	int m_errors;
	QString m_errMsg;
    QStringList m_codecList;
	
	//menu actions
	QAction *removeAct;
	QAction *renameAct;
	QAction *toFATAct;
	QAction *metaDataAct;
	
	QStringList frequencies;
	QStringList bitrates;
	QString m_curBitRate;
	QString m_curFreq;
	
#ifdef HAVE_TAGLIB
	Ui::TagDialog *m_tagDlg;
	QWidget *m_tagWDlg;
#endif	
};

#endif

